%function im2=remove_slp_nc(im,gstd1,gstd2,w,gstd3)
%
% Speckle reduction using normalized averaging
% Assumes im = sqrt(kinect_ir_image)
%
% IM    Input image (use sqrt of raw data)
% GSTD1 Typical size of speckle (default 0.575)
% GSTD2 Integration size for background level (default 2.3)
% W     Weight for normalized averaging (default 9.0)
% GSTD3 Normalized averaging size (default 3.4)
%
% The algorithm and its parameters are described in the paper:
% E. Ringaby, P-E. Forssen, "Scan Rectification for Structured Light
% Sensors with Rolling Shutters", ICCV 2011
%
% (c) Per-Erik Forssen, Jan 2011
function [im2,p]=remove_slp_nc(im,gstd1,gstd2,w,gstd3)

if nargin<5,gstd3=3.4;end
if nargin<4,w=9.0;end
if nargin<3,gstd2=2.3;end
if nargin<2,gstd1=0.575;end

x=-9:9; % Coordinates for filter coeffs
% Define filters for pattern detector
gf1=exp(-.5*(x/gstd1).^2);gf1=gf1/sum(gf1(:));
gf2=exp(-.5*(x/gstd2).^2);gf2=gf2/sum(gf2(:));

p1=conv2(gf1,gf1,im,'same');
p2=conv2(gf2,gf2,im,'same');
%p=1-min(1,max(0,p1-p2)*w);
p=1-min(1,max(0,(p1-p2)./p2)*w); % DoG/mean

% Normalized averaging kernel
gf3=exp(-.5*(x/gstd3).^2);gf3=gf3/sum(gf3(:));

nc=conv2(gf3,gf3,p,'same')+eps;
im2=conv2(gf3,gf3,im.*p,'same')./nc;
