%
% Demo of remove_slp_nc on a NIR image
%
% The algorithm and its parameters are described in the paper:
% E. Ringaby, P-E. Forssen, "Scan Rectification for Structured Light
% Sensors with Rolling Shutters", ICCV 2011
%
% (c) Per-Erik Forssen, Sep 2011

% Load image
im_raw = imread('image_nir.png');

% First, convert to range [0,1], and apply gamma correction

nfactor=255; % For 8 bit images, divide by 255
% For 10 bit images, instead divide by 1023
if isa(im_raw,'uint16') nfactor=1023;end

im_gc = sqrt(double(im_raw)/nfactor);

% Apply structured light pattern removal
gstd1=0.575;
gstd2=2.3;
w=9.0;
gstd3=3.4;
im = remove_slp_nc(im_gc,gstd1,gstd2,w,gstd3);

% Optionally stretch contrast interval
% (for better visualization)
il=min(im(:));
ih=max(im(:));
im = (im-il)/(ih-il);

% Display results

figure(1);clf

subplot(2,2,1);
image(im_raw);axis image
colormap(gray(256))
title('Image from sensor');

subplot(2,2,2);
image(repmat(im_gc,[1 1 3]));axis image
title('Gamma corrected');

subplot(2,1,2);
image(repmat(im,[1 1 3]));axis image
title('After after SLP removal');
